@@ -1,7 +1,6 @@
 package service // import "github.com/docker/docker/volume/service"
 
 import (
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"testing"
@@ -15,7 +14,7 @@ import (
 func TestSetGetMeta(t *testing.T) {
 	t.Parallel()
 
-	dir, err := ioutil.TempDir("", "test-set-get")
+	dir, err := os.MkdirTemp("", "test-set-get")
 	assert.NilError(t, err)
 	defer os.RemoveAll(dir)
 
